@@ -10,6 +10,14 @@ use utils::parse;
 
 const EXCHANGE_NAME: &str = "mexc";
 
+#[test_case(MarketType::Spot)]
+#[test_case(MarketType::InverseSwap)]
+#[test_case(MarketType::LinearSwap)]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
+async fn test_crawl_trade_all(market_type: MarketType) {
+    test_all_symbols!(crawl_trade, EXCHANGE_NAME, market_type, MessageType::Trade)
+}
+
 #[test_case(MarketType::Spot, "BTC_USDT")]
 #[test_case(MarketType::LinearSwap, "BTC_USDT")]
 #[test_case(MarketType::InverseSwap, "BTC_USD")]
@@ -93,7 +101,7 @@ async fn test_crawl_ticker(market_type: MarketType, symbol: &str) {
 #[test_case(MarketType::Spot)]
 #[test_case(MarketType::LinearSwap)]
 #[test_case(MarketType::InverseSwap)]
-#[tokio::test(flavor = "multi_thread")]
+#[tokio::test(flavor = "multi_thread", worker_threads = 8)]
 async fn test_crawl_candlestick(market_type: MarketType) {
     gen_test_crawl_candlestick!(EXCHANGE_NAME, market_type)
 }
