@@ -31,21 +31,18 @@ pub(crate) fn parse(msg: Message) -> bool {
 macro_rules! test_one_symbol {
     ($crawl_func:ident, $exchange:expr, $market_type:expr, $symbol:expr, $msg_type:expr) => {{
         let (tx, rx) = std::sync::mpsc::channel();
-        let mut messages = Vec::new();
         let symbols = vec![$symbol.to_string()];
-        $crawl_func($exchange, $market_type, Some(&symbols), tx, Some(0));
+        tokio::task::spawn(async move {
+            $crawl_func($exchange, $market_type, Some(&symbols), tx).await;
+        });
 
-        for msg in rx {
-            messages.push(msg);
-        }
+        let msg = rx.recv().unwrap();
 
-        assert!(!messages.is_empty());
-        assert_eq!(messages[0].exchange, $exchange.to_string());
-        assert_eq!(messages[0].market_type, $market_type);
-        assert_eq!(messages[0].msg_type, $msg_type);
-        for msg in messages {
-            assert!(parse(msg));
-        }
+        assert_eq!(msg.exchange, $exchange.to_string());
+        assert_eq!(msg.market_type, $market_type);
+        assert_eq!(msg.msg_type, $msg_type);
+
+        assert!(tokio::task::block_in_place(move || parse(msg)));
     }};
 }
 
@@ -53,26 +50,54 @@ macro_rules! test_one_symbol {
 macro_rules! test_all_symbols {
     ($crawl_func:ident, $exchange:expr, $market_type:expr, $msg_type:expr) => {{
         let (tx, rx) = std::sync::mpsc::channel();
-        let mut messages = Vec::new();
-        let symbols = if $market_type == MarketType::Spot {
-            let spot_symbols = fetch_symbols_retry($exchange, $market_type);
-            get_hot_spot_symbols($exchange, &spot_symbols)
-        } else {
-            fetch_symbols_retry($exchange, $market_type)
-        };
-        $crawl_func($exchange, $market_type, Some(&symbols), tx, Some(0));
+        tokio::task::spawn(async move {
+            $crawl_func($exchange, $market_type, None, tx).await;
+        });
 
-        for msg in rx {
-            messages.push(msg);
-        }
+        let msg = rx.recv().unwrap();
 
-        assert!(!messages.is_empty());
-        assert_eq!(messages[0].exchange, $exchange.to_string());
-        assert_eq!(messages[0].market_type, $market_type);
-        assert_eq!(messages[0].msg_type, $msg_type);
-        for msg in messages {
-            assert!(parse(msg));
-        }
+        assert_eq!(msg.exchange, $exchange.to_string());
+        assert_eq!(msg.market_type, $market_type);
+        assert_eq!(msg.msg_type, $msg_type);
+
+        assert!(tokio::task::block_in_place(move || parse(msg)));
+    }};
+}
+
+#[allow(unused_macros)]
+macro_rules! test_crawl_restful {
+    ($crawl_func:ident, $exchange:expr, $market_type:expr, $symbol:expr, $msg_type:expr) => {{
+        let (tx, rx) = std::sync::mpsc::channel();
+        let symbols = vec![$symbol.to_string()];
+        std::thread::spawn(move || {
+            $crawl_func($exchange, $market_type, Some(&symbols), tx);
+        });
+
+        let msg = rx.recv().unwrap();
+
+        assert_eq!(msg.exchange, $exchange.to_string());
+        assert_eq!(msg.market_type, $market_type);
+        assert_eq!(msg.msg_type, $msg_type);
+
+        assert!(parse(msg));
+    }};
+}
+
+#[allow(unused_macros)]
+macro_rules! test_crawl_restful_all_symbols {
+    ($crawl_func:ident, $exchange:expr, $market_type:expr, $msg_type:expr) => {{
+        let (tx, rx) = std::sync::mpsc::channel();
+        std::thread::spawn(move || {
+            $crawl_func($exchange, $market_type, None, tx);
+        });
+
+        let msg = rx.recv().unwrap();
+
+        assert_eq!(msg.exchange, $exchange.to_string());
+        assert_eq!(msg.market_type, $market_type);
+        assert_eq!(msg.msg_type, $msg_type);
+
+        assert!(parse(msg));
     }};
 }
 
@@ -80,18 +105,17 @@ macro_rules! test_all_symbols {
 macro_rules! gen_test_crawl_candlestick {
     ($exchange:expr, $market_type:expr) => {{
         let (tx, rx) = std::sync::mpsc::channel();
-        let mut messages = Vec::new();
-        crawl_candlestick($exchange, $market_type, None, tx, Some(0));
-        for msg in rx {
-            messages.push(msg);
-        }
-        assert!(!messages.is_empty());
-        assert_eq!(messages[0].exchange, EXCHANGE_NAME.to_string());
-        assert_eq!(messages[0].market_type, $market_type);
-        assert_eq!(messages[0].msg_type, MessageType::Candlestick);
-        for msg in messages {
-            assert!(parse(msg));
-        }
+        tokio::task::spawn(async move {
+            crawl_candlestick($exchange, $market_type, None, tx).await;
+        });
+
+        let msg = rx.recv().unwrap();
+
+        assert_eq!(msg.exchange, $exchange.to_string());
+        assert_eq!(msg.market_type, $market_type);
+        assert_eq!(msg.msg_type, MessageType::Candlestick);
+
+        assert!(tokio::task::block_in_place(move || parse(msg)));
     }};
 }
 
@@ -99,11 +123,15 @@ macro_rules! gen_test_crawl_candlestick {
 macro_rules! gen_test_subscribe_symbol {
     ($exchange:expr, $market_type:expr, $symbol:expr) => {{
         let (tx, rx) = std::sync::mpsc::channel();
+        tokio::task::spawn(async move {
+            let msg_types = vec![MessageType::Trade, MessageType::L2Event];
+            subscribe_symbol($exchange, $market_type, $symbol, &msg_types, tx).await;
+        });
+
         let mut messages = Vec::new();
-        let msg_types = vec![MessageType::Trade, MessageType::L2Event];
-        subscribe_symbol($exchange, $market_type, $symbol, &msg_types, tx, Some(0));
         for msg in rx {
             messages.push(msg);
+            break;
         }
         assert!(!messages.is_empty());
     }};
